==> deepin-boot-maker_6.0.1.tar.xz: BUILD/src/translations/deepin-boot-maker_ka.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ka" version="2.1">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="16"/>
        <source>Disk Format Error: Please reformat it or disable &quot;Auto scan USB storage devices&quot; in Security Center</source>
        <translation>დისკის ფორმატირები შეცდომა: გთხოვთ გადააფორმატეთ ან გათიშეთ &quot;USB მოწყობილობების ავტომატური დასკანერება&quot;</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="19"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation>დისკის ფორმატირების შეცდომა, გთხოვთ განმეორებით დააფორმატოთ</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="24"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation>არასაკმარისი სივრცე: გთხოვთ დარწმუნდით, რომ დისკზე არის საკმარისი სივრცე</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="27"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>დისკის მიერთების შეცდომა: დააერთეთ დისკი განმეორებით ან გადატვირთეთ კომპიუტერი</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="30"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>სურათის დეკომპრესიის შეცდომა: გთხოვთ გადაამოწმეთ იმიჯის md5 checksum</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="33"/>
        <source>Internal Error</source>
        <translation>შეიდა შეცდომა</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="79"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation>ჩატვირთვადი მედიის შემქმნელი არის მარტივი ხელსაწყო USB გარე მეხსიერებაზე ჩატვირთვადი მედიის შესაქმნელად</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="81"/>
        <source>Boot Maker</source>
        <translation>ჩატვირთვადი მედიის შემქმნელი</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="116"/>
        <source>Drag an ISO image file here</source>
        <translation>გადმოიტანეთ ISO ფაილი აქ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="125"/>
        <source>OR</source>
        <translation>ან</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="82"/>
        <location filename="../app/view/isoselectview.cpp" line="140"/>
        <source>Select an ISO image file</source>
        <translation>აირჩიეთ ISO  ფაილი</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="170"/>
        <source>Next</source>
        <translation>შემდეგი</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="225"/>
        <source>Reselect an ISO image file</source>
        <translation>განმეორებით აირჩიეთ ISO ფაილი</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="188"/>
        <source>Illegal ISO image file</source>
        <translation>არასწორი ISO ფაილი</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="328"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>ISO ფაილი აღმოჩენა, გთხოვთ დაელოდოთ</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="51"/>
        <source>Burning</source>
        <translation>ჩაწერა</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="63"/>
        <source>Burning, please wait...</source>
        <translation>ჩაწერა, გთხოვთ დაელოდოთ...</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="71"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>ჩაწერის პროცესში არ გამორთოთ კომპიუტერი ან გამოაერთოთ დისკი</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="85"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>გაუქმება</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="40"/>
        <source>Removable Disk</source>
        <translation>ხსნადი დისკი</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="224"/>
        <location filename="../libdbm/util/utils.cpp" line="370"/>
        <source>Removable disk</source>
        <translation>ხსნადი დისკი</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="122"/>
        <source>Boot Maker</source>
        <translation>ჩატვირთვადი მედიის შემქმნელი</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="104"/>
        <source>Reboot now</source>
        <translation>გადატვირთვა</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="56"/>
        <source>Successful</source>
        <translation>წარმატება</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="95"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>დასრულება</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="169"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>შეცდომის ლოგი ავტომატურად გაიგზავნება. გაუმჯობესება შეუძლებელია თქვენი გამოხმაურების გარეშე</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="170"/>
        <source>Submit Feedback</source>
        <translation>გამოხმაურება</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="193"/>
        <source>After-Sale Services</source>
        <translation>გაყიდვების შემდგომი მომსახურება</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="206"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>დახურვა</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="214"/>
        <source>Sorry, process failed</source>
        <translation>უკაცრავად, პროცესი წარუმატებელია</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="215"/>
        <source>Process failed</source>
        <translation>პროცესი წარუმატებელია</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="13"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>მიმდინარეობს მონაცემების დადასტურება უსაფრხოთ გამოერთებისათვის, გთხოვთ დაელოდოთ...</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="92"/>
        <source>Select a partition</source>
        <translation>აირჩიეთ დანაყოფი</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="117"/>
        <source>Format the partition</source>
        <translation>დანაყოფის დაფორმატება</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="170"/>
        <source>Start</source>
        <translation>დაწყება</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="231"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>დანაყოფის დაფორმატებისას თქვენი ამჟამინდელი ინფორმაცია წაიშლება. დაფორმატებამდე გთხოვთ შეინახოთ ფაილები</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="377"/>
        <location filename="../app/view/usbselectview.cpp" line="388"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="380"/>
        <source>You have selected the ISO image in this USB flash drive. Formatting it will erase all your files. Please reselect the image file or cancel the formatting.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="384"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>გაუქმება</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="391"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>დანაყოფის დაფორმატებისას თქვენი ამჟამინდელი ინფორმაცია ჩანაცვლდება ახლით. დაფორმატებამდე გთხოვთ შეინახოთ ფაილები</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="407"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>დისკის ფორმატირების შეცდომა: გთხოვთ დააფორმატოთ დისკი FAT32 ფორმატში</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="153"/>
        <source>No disk available</source>
        <translation>დისკი მიუწვდომელია</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="174"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>უკან</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="358"/>
        <source>Format Partition</source>
        <translation>დანაყოფის დაფორმატება</translation>
    </message>
</context>
</TS>

==> deepin-boot-maker_6.0.8.tar.xz: BUILD/src/translations/deepin-boot-maker_ka.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ka">
<context>
    <name>BMHandler</name>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="20"/>
        <source>Disk Format Error: Please reformat it or disable "Auto scan USB storage devices" in Security Center</source>
        <translation>დისკის ფორმატირები შეცდომა: გთხოვთ გადააფორმატეთ ან გათიშეთ "USB მოწყობილობების ავტომატური დასკანერება"</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="23"/>
        <source>Disk Format Error: Please reformat it</source>
        <translation>დისკის ფორმატირების შეცდომა, გთხოვთ განმეორებით დააფორმატოთ</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="28"/>
        <source>Insufficient disk Space: Ensure that the disk has enough free space</source>
        <translation>არასაკმარისი სივრცე: გთხოვთ დარწმუნდით, რომ დისკზე არის საკმარისი სივრცე</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="31"/>
        <source>Disk Mount Error: Insert the disk again or reboot to retry</source>
        <translation>დისკის მიერთების შეცდომა: დააერთეთ დისკი განმეორებით ან გადატვირთეთ კომპიუტერი</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="34"/>
        <source>Image Decompression Error: Verify md5 checksum of the image to ensure its integrity</source>
        <translation>სურათის დეკომპრესიის შეცდომა: გთხოვთ გადაამოწმეთ იმიჯის md5 checksum</translation>
    </message>
    <message>
        <location filename="../libdbm/backend/bmhandler.cpp" line="37"/>
        <source>Internal Error</source>
        <translation>შეიდა შეცდომა</translation>
    </message>
</context>
<context>
    <name>BMWindow</name>
    <message>
        <location filename="../app/bmwindow.cpp" line="69"/>
        <source>Boot Maker is a simple tool to write system image files into USB flash drives and other media.</source>
        <translation>ჩატვირთვადი მედიის შემქმნელი არის მარტივი ხელსაწყო USB გარე მეხსიერებაზე ჩატვირთვადი მედიის შესაქმნელად</translation>
    </message>
    <message>
        <location filename="../app/bmwindow.cpp" line="71"/>
        <source>Boot Maker</source>
        <translation>ჩატვირთვადი მედიის შემქმნელი</translation>
    </message>
</context>
<context>
    <name>ISOSelectView</name>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="114"/>
        <source>Drag an ISO image file here</source>
        <translation>გადმოიტანეთ ISO ფაილი აქ</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="126"/>
        <source>OR</source>
        <translation>ან</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="80"/>
        <source>Select an ISO image file</source>
        <translation>აირჩიეთ ISO  ფაილი</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="171"/>
        <source>Next</source>
        <translation>შემდეგი</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="231"/>
        <source>Reselect an ISO image file</source>
        <translation>განმეორებით აირჩიეთ ISO ფაილი</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="191"/>
        <source>Illegal ISO image file</source>
        <translation>არასწორი ISO ფაილი</translation>
    </message>
    <message>
        <location filename="../app/view/isoselectview.cpp" line="378"/>
        <source>Detecting ISO file, please wait...</source>
        <translation>ISO ფაილი აღმოჩენა, გთხოვთ დაელოდოთ</translation>
    </message>
</context>
<context>
    <name>ProgressView</name>
    <message>
        <location filename="../app/view/progressview.cpp" line="34"/>
        <source>Burning</source>
        <translation>ჩაწერა</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="46"/>
        <source>Burning, please wait...</source>
        <translation>ჩაწერა, გთხოვთ დაელოდოთ...</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="54"/>
        <source>Do not remove the disk or shut down the computer during the process</source>
        <translation>ჩაწერის პროცესში არ გამორთოთ კომპიუტერი ან გამოაერთოთ დისკი</translation>
    </message>
    <message>
        <location filename="../app/view/progressview.cpp" line="68"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>გაუქმება</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../libdbm/util/deviceinfo.h" line="23"/>
        <source>Removable Disk</source>
        <translation>ხსნადი დისკი</translation>
    </message>
    <message>
        <location filename="../libdbm/util/utils.cpp" line="227"/>
        <source>Removable disk</source>
        <translation>ხსნადი დისკი</translation>
    </message>
    <message>
        <location filename="../app/main.cpp" line="105"/>
        <source>Boot Maker</source>
        <translation>ჩატვირთვადი მედიის შემქმნელი</translation>
    </message>
</context>
<context>
    <name>ResultView</name>
    <message>
        <location filename="../app/view/resultview.cpp" line="88"/>
        <source>Reboot now</source>
        <translation>გადატვირთვა</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="52"/>
        <source>Successful</source>
        <translation>წარმატება</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="79"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>დასრულება</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="174"/>
        <source>The error log will be uploaded automatically with the feedback. We cannot improve without your feedback</source>
        <translation>შეცდომის ლოგი ავტომატურად გაიგზავნება. გაუმჯობესება შეუძლებელია თქვენი გამოხმაურების გარეშე</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="175"/>
        <source>Submit Feedback</source>
        <translation>გამოხმაურება</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="198"/>
        <source>After-Sale Services</source>
        <translation>გაყიდვების შემდგომი მომსახურება</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="213"/>
        <source>Close</source>
        <comment>button</comment>
        <translation>დახურვა</translation>
    </message>
    <message>
        <location filename="../app/view/resultview.cpp" line="222"/>
        <source>Sorry, process failed</source>
        <translation>უკაცრავად, პროცესი წარუმატებელია</translation>
    </message>
</context>
<context>
    <name>UnmountUsbView</name>
    <message>
        <location filename="../app/view/unmountusbview.cpp" line="17"/>
        <source>Verifying data and safely removing the media, please wait...</source>
        <translation>მიმდინარეობს მონაცემების დადასტურება უსაფრხოთ გამოერთებისათვის, გთხოვთ დაელოდოთ...</translation>
    </message>
</context>
<context>
    <name>UsbSelectView</name>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="75"/>
        <source>Select a partition</source>
        <translation>აირჩიეთ დანაყოფი</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="101"/>
        <source>Format the partition</source>
        <translation>დანაყოფის დაფორმატება</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="154"/>
        <source>Start</source>
        <translation>დაწყება</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="223"/>
        <source>Formatting will erase all data on the partition, but can increase the success rate, please confirm before proceeding</source>
        <translation>დანაყოფის დაფორმატებისას თქვენი ამჟამინდელი ინფორმაცია წაიშლება. დაფორმატებამდე გთხოვთ შეინახოთ ფაილები</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="378"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>OK</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="377"/>
        <source>You have selected the ISO image in this USB flash drive. Formatting it will erase all your files. Please reselect the image file or cancel the formatting.</source>
        <translation>თქვენ არჩეულია ამ უსბ ფლაშ დრივეში აისო სურათი. ფორმატირება შეიძლება წაშალოს თქვენი ყველა ფაილი. გთხოვთ აისო სურათის ფაილს ახალად არჩიოთ ან გაუქმოთ ფორმატირება.</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="385"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>გაუქმება</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="384"/>
        <source>Formatting the partition will overwrite all data, please have a backup before proceeding.</source>
        <translation>დანაყოფის დაფორმატებისას თქვენი ამჟამინდელი ინფორმაცია ჩანაცვლდება ახლით. დაფორმატებამდე გთხოვთ შეინახოთ ფაილები</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="404"/>
        <source>Disk Format Error: Please format the partition with FAT32</source>
        <translation>დისკის ფორმატირების შეცდომა: გთხოვთ დააფორმატოთ დისკი FAT32 ფორმატში</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="137"/>
        <source>No disk available</source>
        <translation>დისკი მიუწვდომელია</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="158"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>უკან</translation>
    </message>
    <message>
        <location filename="../app/view/usbselectview.cpp" line="377"/>
        <source>Format Partition</source>
        <translation>დანაყოფის დაფორმატება</translation>
    </message>
</context>
</TS>
